@@ -10,8 +10,10 @@ import inquirer
 import rich
 from lightning_cloud.openapi import V1LightningappInstanceState, V1LightningworkState
 from lightning_cloud.openapi.rest import ApiException
+from lightning_utilities.core.imports import RequirementCache
 from requests.exceptions import ConnectionError
 
+import lightning_app.core.constants as constants
 from lightning_app import __version__ as ver
 from lightning_app.cli import cmd_init, cmd_install, cmd_pl_init, cmd_react_ui_init
 from lightning_app.cli.cmd_apps import _AppManager
@@ -43,6 +45,7 @@ from lightning_app.utilities.exceptions import _ApiExceptionHandler, LogLinesLim
 from lightning_app.utilities.login import Auth
 from lightning_app.utilities.logs_socket_api import _ClusterLogsSocketAPI
 from lightning_app.utilities.network import LightningClient
+from lightning_app.utilities.port import _find_lit_app_port
 
 logger = Logger(__name__)
 
@@ -229,11 +232,12 @@ def _run_app(
     env: tuple,
     secret: tuple,
     run_app_comment_commands: bool,
+    enable_basic_auth: str,
 ) -> None:
 
     if not os.path.exists(file):
         original_file = file
-        file = cmd_install.gallery_apps_and_components(file, True, "latest", overwrite=False)  # type: ignore[assignment]  # noqa E501
+        file = cmd_install.gallery_apps_and_components(file, True, "latest", overwrite=True)  # type: ignore[assignment]  # noqa E501
         if file is None:
             click.echo(f"The provided entrypoint `{original_file}` doesn't exist.")
             sys.exit(1)
@@ -265,6 +269,9 @@ def _run_app(
 
     secrets = _format_input_env_variables(secret)
 
+    port = _find_lit_app_port(constants.APP_SERVER_PORT)
+    constants.APP_SERVER_PORT = port
+
     click.echo("Your Lightning App is starting. This won't take long.")
 
     # TODO: Fixme when Grid utilities are available.
@@ -282,6 +289,8 @@ def _run_app(
         secrets=secrets,
         cluster_id=cluster_id,
         run_app_comment_commands=run_app_comment_commands,
+        enable_basic_auth=enable_basic_auth,
+        port=port,
     )
     if runtime_type == RuntimeType.CLOUD:
         click.echo("Application is ready in the cloud")
@@ -327,6 +336,12 @@ def run() -> None:
     default=False,
     help="run environment setup commands from the app comments.",
 )
+@click.option(
+    "--enable-basic-auth",
+    type=str,
+    default="",
+    help="Enable basic authentication for the app and use credentials provided in the format username:password",
+)
 def run_app(
     file: str,
     cloud: bool,
@@ -340,6 +355,7 @@ def run_app(
     secret: tuple,
     app_args: tuple,
     run_app_comment_commands: bool,
+    enable_basic_auth: str,
 ) -> None:
     """Run an app from a file."""
     _run_app(
@@ -354,20 +370,15 @@ def run_app(
         env,
         secret,
         run_app_comment_commands,
+        enable_basic_auth,
     )
 
 
-@_main.group(hidden=True)
-def fork() -> None:
-    """Fork an application."""
-    pass
-
-
-@_main.group(hidden=True)
-def stop() -> None:
-    """Stop your application."""
-    pass
+if RequirementCache("lightning-fabric>=1.9.0.dev0") or RequirementCache("lightning>=1.9.0.dev0"):
+    # lightning.fabric.cli may not be available when installing only standalone lightning-app package
+    from lightning_fabric.cli import _run_model
 
+    run.add_command(_run_model)
 
 _main.add_command(get_list)
 _main.add_command(delete)
