@@ -50,13 +50,13 @@ def create() -> None:
     help="Edit the cluster specs before submitting them to the API server.",
 )
 @click.option(
-    "--async",
-    "do_async",
+    "--sync",
+    "do_sync",
     type=bool,
     required=False,
     default=False,
     is_flag=True,
-    help="This flag makes the CLI return immediately and lets the cluster creation happen in the background.",
+    help="This flag makes the CLI wait until cluster creation completes.",
 )
 def create_cluster(
     cluster_id: str,
@@ -66,7 +66,7 @@ def create_cluster(
     provider: str,
     edit_before_creation: bool,
     enable_performance: bool,
-    do_async: bool,
+    do_sync: bool,
     **kwargs: Any,
 ) -> None:
     """Create a Lightning AI BYOC compute cluster with your cloud provider credentials."""
@@ -81,7 +81,7 @@ def create_cluster(
         external_id=external_id,
         edit_before_creation=edit_before_creation,
         cost_savings=not enable_performance,
-        do_async=do_async,
+        do_async=not do_sync,
     )
 
 
