@@ -2,9 +2,9 @@ import abc
 import base64
 import os
 import platform
-from pathlib import Path
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, TYPE_CHECKING
 
+import requests
 import uvicorn
 from fastapi import FastAPI
 from lightning_utilities.core.imports import compare_version, module_available
@@ -14,6 +14,9 @@ from lightning_app.core.work import LightningWork
 from lightning_app.utilities.app_helpers import Logger
 from lightning_app.utilities.imports import _is_torch_available, requires
 
+if TYPE_CHECKING:
+    from lightning_app.frontend.frontend import Frontend
+
 logger = Logger(__name__)
 
 # Skip doctests if requirements aren't available
@@ -48,23 +51,97 @@ class Image(BaseModel):
     image: Optional[str]
 
     @staticmethod
-    def _get_sample_data() -> Dict[Any, Any]:
-        imagepath = Path(__file__).parent / "catimage.png"
-        with open(imagepath, "rb") as image_file:
-            encoded_string = base64.b64encode(image_file.read())
-        return {"image": encoded_string.decode("UTF-8")}
+    def get_sample_data() -> Dict[Any, Any]:
+        url = "https://raw.githubusercontent.com/Lightning-AI/LAI-Triton-Server-Component/main/catimage.png"
+        img = requests.get(url).content
+        img = base64.b64encode(img).decode("UTF-8")
+        return {"image": img}
+
+    @staticmethod
+    def request_code_sample(url: str) -> str:
+        return (
+            """import base64
+from pathlib import Path
+import requests
+
+imgurl = "https://raw.githubusercontent.com/Lightning-AI/LAI-Triton-Server-Component/main/catimage.png"
+img = requests.get(imgurl).content
+img = base64.b64encode(img).decode("UTF-8")
+response = requests.post('"""
+            + url
+            + """', json={
+"image": img
+})
+# If you are using basic authentication for your app, you should add your credentials to the request:
+# response = requests.post('"""
+            + url
+            + """', json={
+# "image": img
+# }, auth=requests.auth.HTTPBasicAuth('your_username', 'your_password'))
+"""
+        )
+
+    @staticmethod
+    def response_code_sample() -> str:
+        return """img = response.json()["image"]
+img = base64.b64decode(img.encode("utf-8"))
+Path("response.png").write_bytes(img)
+"""
+
+
+class Category(BaseModel):
+    category: Optional[int]
+
+    @staticmethod
+    def get_sample_data() -> Dict[Any, Any]:
+        return {"prediction": 463}
+
+    @staticmethod
+    def response_code_sample() -> str:
+        return """print("Predicted category is: ", response.json()["category"])
+"""
+
+
+class Text(BaseModel):
+    text: Optional[str]
+
+    @staticmethod
+    def get_sample_data() -> Dict[Any, Any]:
+        return {"text": "A portrait of a person looking away from the camera"}
+
+    @staticmethod
+    def request_code_sample(url: str) -> str:
+        return (
+            """import base64
+from pathlib import Path
+import requests
+
+response = requests.post('"""
+            + url
+            + """', json={
+"text": "A portrait of a person looking away from the camera"
+})
+# If you are using basic authentication for your app, you should add your credentials to the request:
+# response = requests.post('"""
+            + url
+            + """', json={
+# "text": "A portrait of a person looking away from the camera"
+# }, auth=requests.auth.HTTPBasicAuth('your_username', 'your_password'))
+"""
+        )
 
 
 class Number(BaseModel):
+    # deprecated
+    # TODO remove this in favour of Category
     prediction: Optional[int]
 
     @staticmethod
-    def _get_sample_data() -> Dict[Any, Any]:
+    def get_sample_data() -> Dict[Any, Any]:
         return {"prediction": 463}
 
 
 class PythonServer(LightningWork, abc.ABC):
-
     _start_method = "spawn"
 
     @requires(["torch"])
@@ -128,6 +205,8 @@ class PythonServer(LightningWork, abc.ABC):
         self._input_type = input_type
         self._output_type = output_type
 
+        self.ready = False
+
     def setup(self, *args, **kwargs) -> None:
         """This method is called before the server starts. Override this if you need to download the model or
         initialize the weights, setting up pipelines etc.
@@ -154,8 +233,8 @@ class PythonServer(LightningWork, abc.ABC):
 
     @staticmethod
     def _get_sample_dict_from_datatype(datatype: Any) -> dict:
-        if hasattr(datatype, "_get_sample_data"):
-            return datatype._get_sample_data()
+        if hasattr(datatype, "get_sample_data"):
+            return datatype.get_sample_data()
 
         datatype_props = datatype.schema()["properties"]
         out: Dict[str, Any] = {}
@@ -187,7 +266,15 @@ class PythonServer(LightningWork, abc.ABC):
 
         fastapi_app.post("/predict", response_model=output_type)(predict_fn)
 
-    def configure_layout(self) -> None:
+    def get_code_sample(self, url: str) -> Optional[str]:
+        input_type: Any = self.configure_input_type()
+        output_type: Any = self.configure_output_type()
+
+        if not (hasattr(input_type, "request_code_sample") and hasattr(output_type, "response_code_sample")):
+            return None
+        return f"{input_type.request_code_sample(url)}\n{output_type.response_code_sample()}"
+
+    def configure_layout(self) -> Optional["Frontend"]:
         try:
             from lightning_api_access import APIAccessFrontend
         except ModuleNotFoundError:
@@ -203,17 +290,19 @@ class PythonServer(LightningWork, abc.ABC):
         except TypeError:
             return None
 
-        return APIAccessFrontend(
-            apis=[
-                {
-                    "name": class_name,
-                    "url": url,
-                    "method": "POST",
-                    "request": request,
-                    "response": response,
-                }
-            ]
-        )
+        frontend_payload = {
+            "name": class_name,
+            "url": url,
+            "method": "POST",
+            "request": request,
+            "response": response,
+        }
+
+        code_sample = self.get_code_sample(url)
+        if code_sample:
+            frontend_payload["code_sample"] = code_sample
+
+        return APIAccessFrontend(apis=[frontend_payload])
 
     def run(self, *args: Any, **kwargs: Any) -> Any:
         """Run method takes care of configuring and setting up a FastAPI server behind the scenes.
@@ -225,5 +314,8 @@ class PythonServer(LightningWork, abc.ABC):
         fastapi_app = FastAPI()
         self._attach_predict_fn(fastapi_app)
 
-        logger.info(f"Your app has started. View it in your browser: http://{self.host}:{self.port}")
+        self.ready = True
+        logger.info(
+            f"Your {self.__class__.__qualname__} has started. View it in your browser: http://{self.host}:{self.port}"
+        )
         uvicorn.run(app=fastapi_app, host=self.host, port=self.port, log_level="error")
